async-std implementation

Functions

  • Sends a ping request to ClamAV using a Unix socket connection
  • Sends a ping request to ClamAV using a TCP connection
  • Scans a data buffer for viruses using a Unix socket connection
  • Scans a data buffer for viruses using a TCP connection
  • Scans a file for viruses using a Unix socket connection
  • Scans a file for viruses using a TCP connection